﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.IO;

namespace frmFinal
{
    public partial class frmTranslation : Form
    {
        bool enSearch = true; //Booleans for storing state of whether we're searching Englisn to Ukrainian or vice versa, and default values
        bool ukSearch = false;

        private void switchSearch() //void method definition for switchinig from one search style to the other
        {
            enSearch = !enSearch; //sets Booleans to the opposite of their current values
            ukSearch = !ukSearch;
        }
        public frmTranslation() //form constructor, initializes form
        {
            InitializeComponent();
        }

        private void frmTranslation_Load(object sender, EventArgs e)
        {
            // TODO: This line of code loads data into the 'phrasesDataSet.tblPhrases' table. You can move, or remove it, as needed.
            this.tblPhrasesTableAdapter.Fill(this.phrasesDataSet.tblPhrases); //on load, form table is filled

        }

        private void ukRadio_CheckedChanged(object sender, EventArgs e) //if UK radio button is checked
        {
            tblPhrasesDataGridView.Columns[1].Visible = false; //switch which columns are visible (columns are indexed as an array)
            tblPhrasesDataGridView.Columns[2].Visible = true;
            switchSearch(); //switch which search mode we're in
        }

        private void enRadio_CheckedChanged(object sender, EventArgs e) // if EN radio button is checked
        {
            tblPhrasesDataGridView.Columns[1].Visible = true; //switch which columns are visible (columns are indexed as an array)
            tblPhrasesDataGridView.Columns[2].Visible = false;
            switchSearch(); //switch which search query mode we're in
        } 

        private void searchTextBox_TextChanged(object sender, EventArgs e) //event handler as textbox text is changed
        {
            if (enSearch) //if we're in EN to UK mode
            {
                this.tblPhrasesTableAdapter.FillByEn(this.phrasesDataSet.tblPhrases, searchTextBox.Text); //fill possible match results by EN column
            }
            else if (ukSearch)  //if we're in UK to EN mode
            {
                this.tblPhrasesTableAdapter.FillByUk(this.phrasesDataSet.tblPhrases, searchTextBox.Text); //fill possible match results by UK column
            }
        }

        private void translateButton_Click(object sender, EventArgs e) //event handler for translate button press
        {
            //make sure a row is selected
            if (tblPhrasesDataGridView.SelectedRows.Count == 0)
            {
                MessageBox.Show("Please select a phrase row!");
            }
            else //display all translation data in other columns
            {
                tblPhrasesDataGridView.Columns[1].Visible = true;
                tblPhrasesDataGridView.Columns[2].Visible = true;
                tblPhrasesDataGridView.Columns[3].Visible = true;
            }
        }

        private void editButton_Click(object sender, EventArgs e)
        {
            //get unique ID of row to send to frmDetails class object
            int intID = int.Parse(tblPhrasesDataGridView.CurrentRow.Cells[0].Value.ToString());
            //show details form
            frmDetails detailsForm = new frmDetails(intID);
            detailsForm.ShowDialog();
            //clear search box
            searchTextBox.Clear();
            //repopulate datagridview
            this.tblPhrasesTableAdapter.Fill(this.phrasesDataSet.tblPhrases);
        }

        private void resetButton_Click(object sender, EventArgs e) //event handler for reset button press
        {
            //reset form to default view
            enRadio.Checked = true;  //default radio button positions selected
            ukRadio.Checked = false;
            enSearch = true; //Booleans representing which search is active reset
            ukSearch = false;
            tblPhrasesDataGridView.Columns[2].Visible = false; //Ukrainian and IPA columns made invisible again
            tblPhrasesDataGridView.Columns[3].Visible = false;
        }

        private void exitButton_Click(object sender, EventArgs e) //event handler for main form exit button
        {   
            //copy complete table to file
            try
            {
                StreamWriter OutputFile; //create a StreamWriter object named OutputFile
                OutputFile = File.CreateText("translations.txt"); //associate object with .txt file to be written
                foreach (DataGridViewRow row in tblPhrasesDataGridView.Rows) //for each row in table
                {   
                  
                    OutputFile.WriteLine(row.Cells[0].Value.ToString() + "\t" + row.Cells[1].Value.ToString() + "\t" + row.Cells[2].Value.ToString() + "\t" + row.Cells[3].Value.ToString()); //write row strings to output file
                }
                OutputFile.Close(); //close filestream connection
            }
            catch (Exception ex) //if error in file connection occurs
            {
                MessageBox.Show(ex.Message); //display error message
            }
            Application.Exit(); //exit application
        }

        private void addButton_Click(object sender, EventArgs e) //event handler for add row button click
        {
            this.tblPhrasesTableAdapter.InsertQuery("", "", ""); //uses wizard-based Insert Query to create a new empty row to be edited and have its fields set
        }
    }
}
